diff common/listutil.h @ 70:64c8c6350e60

Add default constructor to certificatelist. Remove Q_OBJECT use
author Andre Heinecke <aheinecke@intevation.de>
date Wed, 19 Mar 2014 11:31:08 +0000
parents 8ffbb48528ae
children 571f68c7a38f
line wrap: on
line diff
--- a/common/listutil.h	Wed Mar 19 11:30:16 2014 +0000
+++ b/common/listutil.h	Wed Mar 19 11:31:08 2014 +0000
@@ -23,7 +23,8 @@
     InvalidSignature = 4, // Signature was invalid
     SeekFailed = 5, // Could not seek in the file
     ReadFailed = 6, // File exists but could not read the file
-    IncompatibleVersion = 7 // The Format Version does not match
+    IncompatibleVersion = 7, // The Format Version does not match
+    NoList = 8 // No list parsed
 } list_status_t;
 
 /* Definitions based on the format */

http://wald.intevation.org/projects/trustbridge/